///////////////////////////////////////////////////////////////////////////////////
// GameStudio main script
////////////////////////////////////////////////////////////////////////////
// Files to over-ride:
// * logodark.bmp - the engine logo, include your game title
// * horizon.pcx - A horizon map displayed over the sky and cloud maps
////////////////////////////////////////////////////////////////////////////
// The PATH keyword gives directories where game files can be found,
// relative to the level directory
path "C:\\Programme\\GStudio6\\template";	// Path to WDL templates subdirectory

////////////////////////////////////////////////////////////////////////////
// The INCLUDE keyword can be used to include further WDL files,
// like those in the TEMPLATE subdirectory, with prefabricated actions
include <movement.wdl>;
include <messages.wdl>;
include <menu.wdl>;		// must be inserted before doors and weapons
include <particle.wdl>; // remove when you need no particles
include <doors.wdl>;		// remove when you need no doors
include <actors.wdl>;   // remove when you need no actors
include <weapons.wdl>;  // remove when you need no weapons
include <war.wdl>;      // remove when you need no fighting
//include <venture.wdl>;	// include when doing an adventure
include <lflare.wdl>;   // remove when you need no lens flares

////////////////////////////////////////////////////////////////////////////
// The engine starts in the resolution given by the follwing vars.
var video_mode = 10;	 // screen size 640x480
var video_depth = 16; // 16 bit colour D3D mode

/////////////////////////////////////////////////////////////////
// Strings and filenames
// change this string to your own starting mission message.
string mission_str = "Mission 1 Starting Problems.";
string level_str = <speznaz1.WMB>; // give file names in angular brackets

/////////////////////////////////////////////////////////////////
// define a splash screen with the required A4/A5 logo
bmap splashmap = <logolite.pcx>; // the default logo in templates
panel splashscreen {
	bmap = splashmap;
	flags = refresh,d3d;
}

////////////////////////////////////////////////////////////////////////////


/////////////////////////////////////////////////////////////////
// The main() function is started at game start
function main()
{
// set some common flags and variables
//	warn_level = 2;	// announce bad texture sizes and bad wdl code
	tex_share = on;	// map entities share their textures

// center the splash screen for non-640x480 resolutions, and display it
	splashscreen.pos_x = (screen_size.x - bmap_width(splashmap))/2;
	splashscreen.pos_y = (screen_size.y - bmap_height(splashmap))/2;
	splashscreen.visible = on;
// wait 3 frames (for triple buffering) until it is flipped to the foreground
	wait(3);

// now load the level
	level_load(level_str);
// freeze the game
	freeze_mode = 1;

// wait the required second, then switch the splashscreen off.
	sleep(30);
  	splashscreen.visible = off;
	bmap_purge(splashmap);	// remove splashscreen from video memory

// load some global variables, like sound volume
	load_status();

// display the initial message
	msg_show(mission_str,10);

// initialize lens flares when edition supports flares
ifdef CAPS_FLARE;
	lensflare_start();
endif;

// use the new 3rd person camera
	move_view_cap = 1;

// un-freeze the game
	freeze_mode = 0;

//	client_move();	// for a possible multiplayer game
// call further functions here...
}

entity cross_hair
{
	type = <cross.pcx>;
	view = camera; // this is visible in the view called 'camera'
	flags = overlay,visible,flare;
	layer = 0;
	scale_x = .05;
	scale_y = .05;
	scale_z = .05;
	x = 50;
	y = 0;
	z = 0;
}

bmap loading_lv = <blank.bmp>;  //Loading screen
panel loadingscreen {
	bmap = loading_lv;   //loading screen name
	flags = refresh,d3d;
}

function load_level()
{
	loadingscreen.pos_x = (screen_size.x - bmap_width(loading_lv))/2;  //centers loading screen
	loadingscreen.pos_y = (screen_size.y - bmap_height(loading_lv))/2;

loadingscreen.visible = on;  //displays loading screen	
wait(3);
sleep(20);
loadingscreen.visible = off;  //clears screen
bmap_purge(loading_lv); 
LOAD_LEVEL <speznaz2.wmb>;  //level name 
  
}

function load_level1()
{
	loadingscreen.pos_x = (screen_size.x - bmap_width(loading_lv))/2;  //centers loading screen
	loadingscreen.pos_y = (screen_size.y - bmap_height(loading_lv))/2;

loadingscreen.visible = on;  //displays loading screen	
wait(3);
sleep(15);
loadingscreen.visible = off;  //clears screen
bmap_purge(loading_lv); 
LOAD_LEVEL <speznaz3.wmb>;  //level name 
  
}


function load_level2()
{
	loadingscreen.pos_x = (screen_size.x - bmap_width(loading_lv))/2;  //centers loading screen
	loadingscreen.pos_y = (screen_size.y - bmap_height(loading_lv))/2;

loadingscreen.visible = on;  //displays loading screen	
wait(3);
sleep(15);
loadingscreen.visible = off;  //clears screen
bmap_purge(loading_lv); 
LOAD_LEVEL <speznaz4.wmb>;  //level name 
  
}


/////////////////////////////////////////////////////////////////
// The following definitions are for the pro edition window composer
// to define the start and exit window of the application.
WINDOW WINSTART
{
	TITLE			"3D GameStudio";
	SIZE			480,320;
	MODE			IMAGE;	//STANDARD;
	BG_COLOR		RGB(240,240,240);
	FRAME			FTYP1,0,0,480,320;
//	BUTTON		BUTTON_START,SYS_DEFAULT,"Start",400,288,72,24;
	BUTTON		BUTTON_QUIT,SYS_DEFAULT,"Abort",400,288,72,24;
	TEXT_STDOUT	"Arial",RGB(0,0,0),10,10,460,280;
}

/* no exit window at all..
WINDOW WINEND
{
	TITLE			"Finished";
	SIZE			540,320;
	MODE	 		STANDARD;
	BG_COLOR		RGB(0,0,0);
	TEXT_STDOUT	"",RGB(255,40,40),10,20,520,270;

	SET FONT		"",RGB(0,255,255);
	TEXT			"Any key to exit",10,270;
}*/
ACTION levelchange //*assign this to a map entity blocking the way out of the level*/!!!!
{

MY.INVISIBLE = ON;       //makes entitie invisible
MY.ENABLE_IMPACT = ON;   //enables player impact
MY.EVENT = load_level;  //function name

} 

ACTION levelchange1 //*assign this to a map entity blocking the way out of the level*/!!!!
{

MY.INVISIBLE = ON;       //makes entitie invisible
MY.ENABLE_IMPACT = ON;   //enables player impact
MY.EVENT = load_level1;  //function name

} 

ACTION levelchange2 //*assign this to a map entity blocking the way out of the level*/!!!!
{

MY.INVISIBLE = ON;       //makes entitie invisible
MY.ENABLE_IMPACT = ON;   //enables player impact
MY.EVENT = load_level2;  //function name

} 



/////////////////////////////////////////////////////////////////
//INCLUDE <debug.wdl>;